==> openGion7.2.8.0_dev.zip: uap/webapps/ge/db/ORACLE/sql/install/01_TABLE/GE58S.sql <==
/****************************************************************************/
/* GE58 ( RFIDﾚｲｱｳﾄﾃｰﾌﾞﾙ )                                                  */
/*                                                                          */
/* Created : 2018/09/28 16:03:20                                            */
/****************************************************************************/

CREATE TABLE GE58 (
   SYSTEM_ID    VARCHAR2 (  10 )                    NOT NULL            /*  10 ｼｽﾃﾑID   */
 , LISTID       VARCHAR2 (  10 )                    NOT NULL            /*  20 帳票ID   */
 , CLM          VARCHAR2 (  30 )                    NOT NULL            /*  30 項目     */
 , KBOUT        VARCHAR2 (   1 )                    NOT NULL            /*  40 出力区分 */
 , DATA1        VARCHAR2 ( 100 )                                        /*  50 ﾃﾞｰﾀ1    */
 , DATA2        VARCHAR2 (  10 )                                        /*  60 ﾃﾞｰﾀ2    */
 , DATA3        VARCHAR2 (  10 )                                        /*  70 ﾃﾞｰﾀ3    */
 , DATA4        VARCHAR2 (  10 )                                        /*  80 ﾃﾞｰﾀ4    */
 , DATA5        VARCHAR2 (  10 )                                        /*  90 ﾃﾞｰﾀ5    */
 , DATA6        VARCHAR2 (  10 )                                        /* 100 ﾃﾞｰﾀ6    */
 , DATA7        VARCHAR2 (  10 )                                        /* 110 ﾃﾞｰﾀ7    */
 , DATA8        VARCHAR2 (  10 )                                        /* 120 ﾃﾞｰﾀ8    */
 , DATA9        VARCHAR2 (  10 )                                        /* 130 ﾃﾞｰﾀ9    */
 , DATA10       VARCHAR2 (  10 )                                        /* 140 ﾃﾞｰﾀ10   */
 , DATA11       VARCHAR2 (  10 )                                        /* 150 ﾃﾞｰﾀ11   */
 , DATA12       VARCHAR2 (  10 )                                        /* 160 ﾃﾞｰﾀ12   */
 , DATA13       VARCHAR2 (  10 )                                        /* 170 ﾃﾞｰﾀ13   */
 , DATA14       VARCHAR2 (  10 )                                        /* 180 ﾃﾞｰﾀ14   */
 , DATA15       VARCHAR2 (  10 )                                        /* 190 ﾃﾞｰﾀ15   */
 , FGJ          VARCHAR2 (   1 )        DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ */
 , DYSET        VARCHAR2 (  14 )                                        /* 820 登録日時 */
 , PGSET        VARCHAR2 (  10 )                                        /* 830 作成PG   */
 , PGPSET       VARCHAR2 (  10 )                                        /* 840 作成親PG */
 , USRSET       VARCHAR2 (  10 )                                        /* 850 作成者   */
 , DYUPD        VARCHAR2 (  14 )                                        /* 860 更新日時 */
 , PGUPD        VARCHAR2 (  10 )                                        /* 870 更新PG   */
 , PGPUPD       VARCHAR2 (  10 )                                        /* 880 更新親PG */
 , USRUPD       VARCHAR2 (  10 )                                        /* 890 更新者   */
)
TABLESPACE GETBL01
STORAGE( INITIAL 16K );

==> openGion7.4.0.0_dev.zip: uap/webapps/ge/db/ORACLE/sql/install/01_TABLE/GE58S.sql <==
/****************************************************************************/
/* GE58 ( RFIDﾚｲｱｳﾄﾃｰﾌﾞﾙ )                                                  */
/*                                                                          */
/* Created : 2020/12/16 08:13:51                                            */
/****************************************************************************/

CREATE TABLE GE58 (
   SYSTEM_ID    VARCHAR2 (  10 )                    NOT NULL            /*  10 ｼｽﾃﾑID   */
 , LISTID       VARCHAR2 (  10 )                    NOT NULL            /*  20 帳票ID   */
 , CLM          VARCHAR2 (  30 )                    NOT NULL            /*  30 項目     */
 , KBOUT        VARCHAR2 (   1 )                    NOT NULL            /*  40 出力区分 */
 , DATA1        VARCHAR2 ( 100 )                                        /*  50 ﾃﾞｰﾀ1    */
 , DATA2        VARCHAR2 (  10 )                                        /*  60 ﾃﾞｰﾀ2    */
 , DATA3        VARCHAR2 (  10 )                                        /*  70 ﾃﾞｰﾀ3    */
 , DATA4        VARCHAR2 (  10 )                                        /*  80 ﾃﾞｰﾀ4    */
 , DATA5        VARCHAR2 (  10 )                                        /*  90 ﾃﾞｰﾀ5    */
 , DATA6        VARCHAR2 (  10 )                                        /* 100 ﾃﾞｰﾀ6    */
 , DATA7        VARCHAR2 (  10 )                                        /* 110 ﾃﾞｰﾀ7    */
 , DATA8        VARCHAR2 (  10 )                                        /* 120 ﾃﾞｰﾀ8    */
 , DATA9        VARCHAR2 (  10 )                                        /* 130 ﾃﾞｰﾀ9    */
 , DATA10       VARCHAR2 (  10 )                                        /* 140 ﾃﾞｰﾀ10   */
 , DATA11       VARCHAR2 (  10 )                                        /* 150 ﾃﾞｰﾀ11   */
 , DATA12       VARCHAR2 (  10 )                                        /* 160 ﾃﾞｰﾀ12   */
 , DATA13       VARCHAR2 (  10 )                                        /* 170 ﾃﾞｰﾀ13   */
 , DATA14       VARCHAR2 (  10 )                                        /* 180 ﾃﾞｰﾀ14   */
 , DATA15       VARCHAR2 (  10 )                                        /* 190 ﾃﾞｰﾀ15   */
 , FGJ          VARCHAR2 (   1 )        DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ */
 , DYSET        VARCHAR2 (  14 )                                        /* 820 作成日時 */
 , PGSET        VARCHAR2 (  10 )                                        /* 830 作成PG   */
 , PGPSET       VARCHAR2 (  10 )                                        /* 840 作成親PG */
 , USRSET       VARCHAR2 (  10 )                                        /* 850 作成者   */
 , DYUPD        VARCHAR2 (  14 )                                        /* 860 更新日時 */
 , PGUPD        VARCHAR2 (  10 )                                        /* 870 更新PG   */
 , PGPUPD       VARCHAR2 (  10 )                                        /* 880 更新親PG */
 , USRUPD       VARCHAR2 (  10 )                                        /* 890 更新者   */
)
TABLESPACE GETBL01
STORAGE( INITIAL 16K );
